@@ -16,15 +16,18 @@ module.exports = function () {
             return allAddresses;
         } else {
             throw e;
-        };
-    };
+        }
+    }
 
     Object.keys(ifaces).forEach(function (iface) {
         var addresses = {};
         var hasAddresses = false;
         ifaces[iface].forEach(function (address) {
             if (!address.internal) {
-                addresses[(address.family || "").toLowerCase()] = address.address;
+                var family = (typeof address.family === 'number')
+                    ? ("ipv" + address.family)
+                    : (address.family || "").toLowerCase();
+                addresses[family] = address.address;
                 hasAddresses = true;
                 if (address.mac && address.mac !== '00:00:00:00:00:00') {
                     addresses.mac = address.mac;
